@@ -12,11 +12,12 @@ class SimpleMapTokenizer(object):
         start_id:
             If set it will be prepended to each input example
     '''
-    def __init__(self, tkn2id, pad_id, max_len=50, start_id=None, id2type=None, cdb=None):
+    def __init__(self, tkn2id, pad_id, start_id=None, end_id=None, max_len=50, id2type=None, cdb=None):
         self.tkn2id = tkn2id
         self.pad_id = pad_id
         self.max_len = max_len
         self.start_id = start_id
+        self.end_id = end_id
         self.id2type = id2type
         self.cdb = cdb
 
@@ -27,7 +28,12 @@ class SimpleMapTokenizer(object):
     def __call__(self, text, return_tensors=False):
         out = {'input_ids': [], 'attention_mask': []}
 
-        out['input_ids'] = [self.start_id] + [self.tkn2id[tkn] for tkn in text.split(" ")]
+        if self.start_id is not None:
+            out['input_ids'] = [self.start_id]
+        out['input_ids'] = out['input_ids'] + [self.tkn2id[tkn] for tkn in text.split(" ")]
+        if self.end_id is not None:
+            out['input_ids'] = out['input_ids'] + [self.end_id]
+
         out['attention_mask'] = [1] * len(out['input_ids'])
 
         if return_tensors:
@@ -74,6 +80,9 @@ class SimpleMapTokenizer(object):
         out = [self.tkn2id[tkn] for tkn in tokens if tkn in self.tkn2id]
         if self.start_id is not None:
             out = [self.start_id] + out
+        if self.end_id is not None:
+            out = out + [self.end_id]
+
         out = out[:self.max_len]
 
         return out
