@@ -3,7 +3,7 @@ import numpy as np
 from medcat.utils.matutils import unitvec
 
 
-def add_to_stream(examples, pt2tkn, last=False, unk_tkn='unk'):
+def add_to_stream(examples, pt2tkn, last=False, prefix=None, unk_tkn='unk'):
     r''' Add information to the patient stream based on patient_id.
 
     Args:
@@ -13,11 +13,17 @@ def add_to_stream(examples, pt2tkn, last=False, unk_tkn='unk'):
         unk_tkn:
             What token will be added if the patient_id is not in pt2tkn
     '''
-    if last:
-        # Append as last token
-        examples['stream'] = [examples['stream'][i] + [pt2tkn.get(examples['patient_id'][i], unk_tkn)] for i in range(len(examples['stream']))]
-    else:
-        examples['stream'] = [[pt2tkn.get(examples['patient_id'][i], unk_tkn)] + examples['stream'][i] for i in range(len(examples['stream']))]
+
+    for i in range(len(examples['stream'])):
+        to_append = [pt2tkn.get(examples['patient_id'][i], unk_tkn)]
+        if prefix is not None:
+            to_append = [prefix] + to_append
+
+        if last:
+            # Append as last token
+            examples['stream'][i] = examples['stream'][i] + to_append
+        else:
+            examples['stream'][i] = to_append + examples['stream'][i]
 
     return examples
 
